import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'pink'); // Pink background to represent the canvas

  // Cat features
  const catFeatures = [
    // Body of the cat
    { x: width / 2, y: height / 2 + 50, r: 100, fill: 'grey' },
    // Head of the cat
    { x: width / 2, y: height / 2 - 30, r: 50, fill: 'grey' },
    // Eyes
    { x: width / 2 - 20, y: height / 2 - 50, r: 10, fill: 'black' },
    { x: width / 2 + 20, y: height / 2 - 50, r: 10, fill: 'black' },
    // Ears
    { x: width / 2 - 30, y: height / 2 - 70, r: 15, fill: 'grey' },
    { x: width / 2 + 30, y: height / 2 - 70, r: 15, fill: 'grey' },
    // Nose
    { x: width / 2, y: height / 2 - 40, r: 5, fill: 'pink' },
    // Mouth (smiling)
    { d: `M ${width / 2 - 15} ${height / 2 - 20} Q ${width / 2} ${height / 2 - 10} ${width / 2 + 15} ${height / 2 - 20}`, stroke: 'black', fill: 'none' },
    // Moustache
    { x1: width / 2 - 10, y1: height / 2 - 30, x2: width / 2 - 30, y2: height / 2 - 35, stroke: 'black' },
    { x1: width / 2 + 10, y1: height / 2 - 30, x2: width / 2 + 30, y2: height / 2 - 35, stroke: 'black' },
    // Legs (bird-like)
    { x1: width / 2 - 20, y1: height / 2 + 70, x2: width / 2 - 30, y2: height / 2 + 90, stroke: 'grey' },
    { x1: width / 2 + 20, y1: height / 2 + 70, x2: width / 2 + 30, y2: height / 2 + 90, stroke: 'grey' },
    // Tail
    { x1: width / 2 + 50, y1: height / 2 + 50, x2: width / 2 + 100, y2: height / 2 + 70, stroke: 'grey' },
    // Hands (arms)
    { x1: width / 2 - 50, y1: height / 2, x2: width / 2 - 70, y2: height / 2 + 30, stroke: 'grey' },
    { x1: width / 2 + 50, y1: height / 2, x2: width / 2 + 70, y2: height / 2 + 30, stroke: 'grey' },
  ];

  // Draw the cat's features
  svg.selectAll('circle')
    .data(catFeatures.filter(d => d.hasOwnProperty('r')))
    .join('circle')
    .attr('cx', d => d.x)
    .attr('cy', d => d.y)
    .attr('r', d => d.r)
    .attr('fill', d => d.fill);

  // Draw the lines and paths
  svg.selectAll('line')
    .data(catFeatures.filter(d => d.hasOwnProperty('x2')))
    .join('line')
    .attr('x1', d => d.x1)
    .attr('y1', d => d.y1)
    .attr('x2', d => d.x2)
    .attr('y2', d => d.y2)
    .attr('stroke', d => d.stroke);

  svg.selectAll('path')
    .data(catFeatures.filter(d => d.hasOwnProperty('d')))
    .join('path')
    .attr('d', d => d.d)
    .attr('stroke', d => d.stroke)
    .attr('fill', d => d.fill);
};
